pub trait ConfigNames {
// Required method
fn with_config_names<R>(self, operation: impl FnOnce(&[&str]) -> R) -> R;
}Expand description
Provides borrowed access to a candidate configuration key list.
Required Methods
Sourcefn with_config_names<R>(self, operation: impl FnOnce(&[&str]) -> R) -> R
fn with_config_names<R>(self, operation: impl FnOnce(&[&str]) -> R) -> R
Invokes operation with this argument as a string slice list.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.