pub struct ConfigPrefixView<'a> { /* private fields */ }Expand description
Read-only prefix view over a Config: key lookups use a logical key
prefix.
This type is named explicitly so other kinds of configuration views can be
added later without overloading a generic ConfigView.
Lookups rewrite keys by prepending prefix, while exposing keys relative to
that prefix.
Implementations
Sourceimpl<'a> ConfigPrefixView<'a>
impl<'a> ConfigPrefixView<'a>
Sourcepub fn prefix(&self) -> &str
pub fn prefix(&self) -> &str
Gets the logical prefix of this view.
Returns
The normalized prefix string (no leading or trailing dot separators).
Sourcepub fn prefix_view(&self, prefix: &str) -> ConfigPrefixView<'a>
pub fn prefix_view(&self, prefix: &str) -> ConfigPrefixView<'a>